@@ -200,6 +200,54 @@ class PreferencesHelperTestCase(unittest.TestCase):
 
         return
 
+    def test_real_unicode_values(self):
+        """ Test with real life unicode values """
+
+        p = self.preferences
+        p.load(self.example)
+
+        class AcmeUIPreferencesHelper(PreferencesHelper):
+            """ A helper! """
+
+            # The path to the preferences node that contains our preferences.
+            preferences_path = 'acme.ui'
+
+            # The traits that we want to initialize from preferences.
+            bgcolor     = Str('blue')
+            width       = Int(50)
+            ratio       = Float(1.0)
+            visible     = Bool(True)
+            description = Unicode(u'')
+            offsets     = List(Int, [1, 2, 3, 4])
+            names       = List(Str, ['joe', 'fred', 'jane'])
+
+        helper = AcmeUIPreferencesHelper()
+
+        first_unicode_str = u'U\xdc\xf2ser'
+        first_utf8_str = 'U\xc3\x9c\xc3\xb2ser'
+
+        original_description = helper.description
+        helper.description = first_unicode_str
+        self.assertEqual(first_unicode_str, helper.description)
+
+
+        second_unicode_str = u'caf\xe9'
+        second_utf8_str = 'caf\xc3\xa9'
+        helper.description = second_unicode_str
+        self.assertEqual(second_unicode_str, helper.description)
+        self.assertEqual(second_unicode_str, p.get('acme.ui.description'))
+
+        p.save(self.example)
+
+        p.load(self.example)
+        self.assertEqual(second_unicode_str, p.get('acme.ui.description'))
+        self.assertEqual(u'True', p.get('acme.ui.visible'))
+        self.assertEqual(True, helper.visible)
+
+        # reset the original description and save the example file
+        helper.description = original_description
+        p.save(self.example)
+
     def test_no_preferences_path(self):
         """ no preferences path """
 
